# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winrt._winrt_windows_ui_text_core import (
    CoreTextRange,
    CoreTextCompositionCompletedEventArgs,
    CoreTextCompositionSegment,
    CoreTextCompositionStartedEventArgs,
    CoreTextEditContext,
    CoreTextFormatUpdatingEventArgs,
    CoreTextLayoutBounds,
    CoreTextLayoutRequest,
    CoreTextLayoutRequestedEventArgs,
    CoreTextSelectionRequest,
    CoreTextSelectionRequestedEventArgs,
    CoreTextSelectionUpdatingEventArgs,
    CoreTextServicesConstants,
    CoreTextServicesManager,
    CoreTextTextRequest,
    CoreTextTextRequestedEventArgs,
    CoreTextTextUpdatingEventArgs,
)

__all__ = [
    "CoreTextFormatUpdatingReason",
    "CoreTextFormatUpdatingResult",
    "CoreTextInputPaneDisplayPolicy",
    "CoreTextInputScope",
    "CoreTextSelectionUpdatingResult",
    "CoreTextTextUpdatingResult",
    "CoreTextRange",
    "CoreTextCompositionCompletedEventArgs",
    "CoreTextCompositionSegment",
    "CoreTextCompositionStartedEventArgs",
    "CoreTextEditContext",
    "CoreTextFormatUpdatingEventArgs",
    "CoreTextLayoutBounds",
    "CoreTextLayoutRequest",
    "CoreTextLayoutRequestedEventArgs",
    "CoreTextSelectionRequest",
    "CoreTextSelectionRequestedEventArgs",
    "CoreTextSelectionUpdatingEventArgs",
    "CoreTextServicesConstants",
    "CoreTextServicesManager",
    "CoreTextTextRequest",
    "CoreTextTextRequestedEventArgs",
    "CoreTextTextUpdatingEventArgs",
]

class CoreTextFormatUpdatingReason(enum.IntEnum):
    NONE = 0
    COMPOSITION_UNCONVERTED = 1
    COMPOSITION_CONVERTED = 2
    COMPOSITION_TARGET_UNCONVERTED = 3
    COMPOSITION_TARGET_CONVERTED = 4

class CoreTextFormatUpdatingResult(enum.IntEnum):
    SUCCEEDED = 0
    FAILED = 1

class CoreTextInputPaneDisplayPolicy(enum.IntEnum):
    AUTOMATIC = 0
    MANUAL = 1

class CoreTextInputScope(enum.IntEnum):
    DEFAULT = 0
    URL = 1
    FILE_PATH = 2
    FILE_NAME = 3
    EMAIL_USER_NAME = 4
    EMAIL_ADDRESS = 5
    USER_NAME = 6
    PERSONAL_FULL_NAME = 7
    PERSONAL_NAME_PREFIX = 8
    PERSONAL_GIVEN_NAME = 9
    PERSONAL_MIDDLE_NAME = 10
    PERSONAL_SURNAME = 11
    PERSONAL_NAME_SUFFIX = 12
    ADDRESS = 13
    ADDRESS_POSTAL_CODE = 14
    ADDRESS_STREET = 15
    ADDRESS_STATE_OR_PROVINCE = 16
    ADDRESS_CITY = 17
    ADDRESS_COUNTRY_NAME = 18
    ADDRESS_COUNTRY_SHORT_NAME = 19
    CURRENCY_AMOUNT_AND_SYMBOL = 20
    CURRENCY_AMOUNT = 21
    DATE = 22
    DATE_MONTH = 23
    DATE_DAY = 24
    DATE_YEAR = 25
    DATE_MONTH_NAME = 26
    DATE_DAY_NAME = 27
    NUMBER = 29
    SINGLE_CHARACTER = 30
    PASSWORD = 31
    TELEPHONE_NUMBER = 32
    TELEPHONE_COUNTRY_CODE = 33
    TELEPHONE_AREA_CODE = 34
    TELEPHONE_LOCAL_NUMBER = 35
    TIME = 36
    TIME_HOUR = 37
    TIME_MINUTE_OR_SECOND = 38
    NUMBER_FULL_WIDTH = 39
    ALPHANUMERIC_HALF_WIDTH = 40
    ALPHANUMERIC_FULL_WIDTH = 41
    CURRENCY_CHINESE = 42
    BOPOMOFO = 43
    HIRAGANA = 44
    KATAKANA_HALF_WIDTH = 45
    KATAKANA_FULL_WIDTH = 46
    HANJA = 47
    HANGUL_HALF_WIDTH = 48
    HANGUL_FULL_WIDTH = 49
    SEARCH = 50
    FORMULA = 51
    SEARCH_INCREMENTAL = 52
    CHINESE_HALF_WIDTH = 53
    CHINESE_FULL_WIDTH = 54
    NATIVE_SCRIPT = 55
    TEXT = 57
    CHAT = 58
    NAME_OR_PHONE_NUMBER = 59
    EMAIL_USER_NAME_OR_ADDRESS = 60
    PRIVATE = 61
    MAPS = 62
    PASSWORD_NUMERIC = 63
    FORMULA_NUMBER = 67
    CHAT_WITHOUT_EMOJI = 68
    DIGITS = 28
    PIN_NUMERIC = 64
    PIN_ALPHANUMERIC = 65

class CoreTextSelectionUpdatingResult(enum.IntEnum):
    SUCCEEDED = 0
    FAILED = 1

class CoreTextTextUpdatingResult(enum.IntEnum):
    SUCCEEDED = 0
    FAILED = 1

